@@ -2,5 +2,6 @@ if (getRversion() >= '2.15.1') globalVariables(c('buttonsFrame',
  'dcFrame', 'dcVariable', 'distFrame', 'distVariable', 'formulaFrame',
  'methodtypeFrame', 'methodtypeVariable', 'outerOperatorsFrame', 
  'rhsVariable', 'subsetFrame', 'subsetVariable', 'top', 'xBox',
- 'yesVariable', 'designmethodVariable', 'designmethodFrame'))
+ 'yesVariable', 'designmethodVariable', 'designmethodFrame',
+ 'IndependentVarBox'))
 
